==> flutter_extensions-1.0.0.tar.gz: lib/src/built/collections.dart <==
import 'dart:math';

import 'package:built_collection/built_collection.dart';
import 'package:flutter_extensions/src/dart/collections/internal.dart';
import 'package:rxdart/rxdart.dart';

extension BuiltListExt<T> on BuiltList<T> {
  T random({Random random}) {
    if (random != null) {
      return this[random.nextInt(length)];
    } else {
      return this[DateTime.now().microsecond % length];
    }
  }

  T circleGet(int index) => this[index % length];
}

extension ListBuilderExt<T> on ListBuilder<T> {
  void removeWhereNull() => removeWhere((value) => value == null);

  void addOrRemove(bool addOrRemove, T value) {
    if (addOrRemove) {
      add(value);
    } else {
      remove(value);
    }
  }

  T random(Random random) => this[random.nextInt(length)];

  T circleGet(int index) => this[index % length];
}

extension SetBuilderExt<T> on SetBuilder<T> {
  void removeWhereNull() => removeWhere((value) => value == null);

  void addOrRemove(bool addOrRemove, T value) {
    if (addOrRemove) {
      add(value);
    } else {
      remove(value);
    }
  }
}

extension BuiltMapExt<K, V> on BuiltMap<K, V> {
  Iterable<T> generateIterable<T>(T Function(K key, V value) generator) =>
      MapUtility.generateIterable(entries, generator);

  bool every(bool test(K key, V value)) => MapUtility.every(entries, test);

  bool any(bool test(K key, V value)) => MapUtility.any(entries, test);

  K getKeyAfter(K key, [int after = 1]) => MapUtility.getElementAfter(keys, key, after);

  K getKeyBefore(K key, [int before = 1]) =>
      MapUtility.getElementBefore(keys, key, before);
}

extension MapBuilderExt<K, V> on MapBuilder<K, V> {
  void removeNullValues() => removeWhere((key, value) => value == null);
}

extension SubjectBuiltMapExt<K, V> on Subject<BuiltMap<K, V>> {
  Future<void> rebuild(void updates(MapBuilder<K, V> builder)) async {
    final oldMap = await first;
    add(oldMap.rebuild(updates));
  }
}

extension SubjectBuiltListExt<V> on Subject<BuiltList<V>> {
  Future<void> rebuild(void updates(ListBuilder<V> builder)) async {
    final oldMap = await first;
    add(oldMap.rebuild(updates));
  }
}

==> flutter_extensions-1.0.1.tar.gz: lib/src/built/collections.dart <==
import 'dart:math';

import 'package:built_collection/built_collection.dart';
import 'package:flutter_extensions/src/dart/collections/internal.dart';

extension BuiltListExt<T> on BuiltList<T> {
  T random({Random random}) {
    if (random != null) {
      return this[random.nextInt(length)];
    } else {
      return this[DateTime.now().microsecond % length];
    }
  }

  T circleGet(int index) => this[index % length];
}

extension ListBuilderExt<T> on ListBuilder<T> {
  void removeWhereNull() => removeWhere((value) => value == null);

  void addOrRemove(bool addOrRemove, T value) {
    if (addOrRemove) {
      add(value);
    } else {
      remove(value);
    }
  }

  T random(Random random) => this[random.nextInt(length)];

  T circleGet(int index) => this[index % length];
}

extension SetBuilderExt<T> on SetBuilder<T> {
  void removeWhereNull() => removeWhere((value) => value == null);

  void addOrRemove(bool addOrRemove, T value) {
    if (addOrRemove) {
      add(value);
    } else {
      remove(value);
    }
  }
}

extension BuiltMapExt<K, V> on BuiltMap<K, V> {
  Iterable<T> generateIterable<T>(T Function(K key, V value) generator) =>
      MapUtility.generateIterable(entries, generator);

  bool every(bool test(K key, V value)) => MapUtility.every(entries, test);

  bool any(bool test(K key, V value)) => MapUtility.any(entries, test);

  K getKeyAfter(K key, [int after = 1]) =>
      MapUtility.getElementAfter(keys, key, after);

  K getKeyBefore(K key, [int before = 1]) =>
      MapUtility.getElementBefore(keys, key, before);
}

extension MapBuilderExt<K, V> on MapBuilder<K, V> {
  void removeNullValues() => removeWhere((key, value) => value == null);
}
